from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UnitsItem")


@attr.s(auto_attribs=True)
class UnitsItem:
    """In and out units"""

    in_: Union[Unset, None, str] = UNSET
    out: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        in_ = self.in_
        out = self.out

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if in_ is not UNSET:
            field_dict["in"] = in_
        if out is not UNSET:
            field_dict["out"] = out

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        in_ = d.pop("in", UNSET)

        out = d.pop("out", UNSET)

        units_item = cls(
            in_=in_,
            out=out,
        )

        return units_item



from enum import Enum


class ProfileSteps(str, Enum):
    VALUE_0 = "API start"
    VALUE_1 = "User validated"
    VALUE_2 = "Calculation API called"
    VALUE_3 = "API result logged"
    VALUE_4 = "Begin actual calculation"
    VALUE_5 = "Done actual calculation"
    VALUE_6 = "Format output done"
    VALUE_7 = "Fluid loaded"
    VALUE_8 = "Converted result"
    VALUE_9 = "Calculation result stored"

    def __str__(self) -> str:
        return str(self.value)

# class ProfileSteps(int, Enum):
#     ApiStart = 0
#     "0 - API start"
#     UserValidated = 1
#     "1 - User validated"
#     CalculationApiCalled = 2
#     "2 - Calculation API called"
#     ApiResultLogged = 3
#     "3 - API result logged"
#     BeginActualCalculation = 4
#     "4 - Begin actual calculation"
#     DoneActualCalculation = 5
#     "5 - Done actual calculation"
#     FormatOutputDone = 6
#     "6 - Format output done"
#     FluidLoaded = 7
#     "7 - Fluid loaded"
#     ConvertedResult = 8
#     "8 - Converted result"
#     CalculationResultStored = 9
#     """9 - Calculation result stored"""

#     def __str__(self) -> str:
#         return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_value_floating_with_out_units_name import ApiValueFloatingWithOutUnitsName
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiValueWithUnitsCompositionArray")


@attr.s(auto_attribs=True)
class ApiValueWithUnitsCompositionArray:
    """Holds compositioninfo"""

    values: Union[Unset, None, List[ApiValueFloatingWithOutUnitsName]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        values: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.values, Unset):
            if self.values is None:
                values = None
            else:
                values = []
                for values_item_data in self.values:
                    values_item = values_item_data.to_dict()

                    values.append(values_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if values is not UNSET:
            field_dict["values"] = values

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        values = []
        _values = d.pop("values", UNSET)
        for values_item_data in _values or []:
            values_item = ApiValueFloatingWithOutUnitsName.from_dict(values_item_data)

            values.append(values_item)

        api_value_with_units_composition_array = cls(
            values=values,
        )

        return api_value_with_units_composition_array



from enum import Enum


class PropertiesCalculationType(int, Enum):
    TP = 0
    "0 - Fixed Temperature/Pressure"
    TV = 1
    "1 - Fixed Temperature/Volume"
    PV = 2
    """2 - Fixed Pressure/Volume"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="CalculationBlockInfo")


@attr.s(auto_attribs=True)
class CalculationBlockInfo:
    """Information for a copolymer block"""

    commponent_id: Union[Unset, str] = UNSET
    block_name: Union[Unset, None, str] = UNSET
    block_massfraction: Union[Unset, float] = UNSET
    sorting_order: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        commponent_id = self.commponent_id
        block_name = self.block_name
        block_massfraction = self.block_massfraction
        sorting_order = self.sorting_order

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if commponent_id is not UNSET:
            field_dict["commponentId"] = commponent_id
        if block_name is not UNSET:
            field_dict["blockName"] = block_name
        if block_massfraction is not UNSET:
            field_dict["blockMassfraction"] = block_massfraction
        if sorting_order is not UNSET:
            field_dict["sortingOrder"] = sorting_order

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        commponent_id = d.pop("commponentId", UNSET)

        block_name = d.pop("blockName", UNSET)

        block_massfraction = d.pop("blockMassfraction", UNSET)

        sorting_order = d.pop("sortingOrder", UNSET)

        calculation_block_info = cls(
            commponent_id=commponent_id,
            block_name=block_name,
            block_massfraction=block_massfraction,
            sorting_order=sorting_order,
        )

        return calculation_block_info



import aiohttp
from typing import Any, Dict

from onlinepvt.models.cloud_point_calculation_input import CloudPointCalculationInput
from onlinepvt.models.cloud_point_calculation_result import CloudPointCalculationResult
from onlinepvt.models.flash_calculation_input import FlashCalculationInput
from onlinepvt.models.flash_calculation_result import FlashCalculationResult
from onlinepvt.models.flashed_property_calculation_input import FlashedPropertyCalculationInput
from onlinepvt.models.flashed_property_calculation_result import FlashedPropertyCalculationResult
from onlinepvt.models.new_fluid_input import NewFluidInput
from onlinepvt.models.new_fluid_result import NewFluidResult
from onlinepvt.models.phasediagram_fixed_temperature_pressure_calculation_input import PhasediagramFixedTemperaturePressureCalculationInput
from onlinepvt.models.phasediagram_fixed_temperature_pressure_calculation_result import PhasediagramFixedTemperaturePressureCalculationResult
from onlinepvt.models.problem_details import ProblemDetails
from onlinepvt.models.request_fluid_input import RequestFluidInput
from onlinepvt.models.request_fluid_result import RequestFluidResult
from onlinepvt.models.sle_point_calculation_input import SlePointCalculationInput
from onlinepvt.models.sle_point_calculation_result import SlePointCalculationResult
from onlinepvt.models.unflashed_property_calculation_input import UnflashedPropertyCalculationInput
from onlinepvt.models.unflashed_property_calculation_result import UnflashedPropertyCalculationResult
from onlinepvt.models.units import Units
from onlinepvt.models.units_item import UnitsItem


class OnlinePvtClient:
    """Class for making the calling to OnlinePvt API easy"""

    def __init__(self, base_url, user_id, access_secret):
        self.__base_url = "{}/api/01/".format(base_url)
        self.__user_id = user_id
        self.__access_secret = access_secret
        self.__session = aiohttp.ClientSession(
            connector=aiohttp.TCPConnector(ssl=False))

    async def cleanup(self):
        await self.__session.close()

    def __append_body(self, body: Dict[str, Any]) -> Dict[str, Any]:
        """Method that appends user_id and access_secret to the body of the request"""
        user = {
            "userId": self.__user_id,
            "accessSecret": self.__access_secret,
        }
        return {**body, **user}

    async def __post_async(self, endpoint: str, json_body: Dict[str, Any], from_dict):
        """Prepare the URL and the body and makes the POST request to the API"""
        url = "{}{endpoint}".format(self.__base_url, endpoint=endpoint)
        json_body = self.__append_body(json_body)
        try:
            async with self.__session.post(url, json=json_body) as resp:
                response = await resp.json()
                if resp.status == 200:
                    return from_dict(response)
                else:
                    return ProblemDetails.from_dict(response)
        except aiohttp.ClientConnectorError as e:
            print('Connection Error', str(e))
            return ProblemDetails.from_dict(e)

    async def request_fluid_async(
        self,
        body: RequestFluidInput,
    ): return await self.__post_async("Fluid/RequestFluid", body.to_dict(), RequestFluidResult.from_dict)

    async def add_new_fluid_async(
        self,
        body: NewFluidInput,
    ): return await self.__post_async("Fluid/AddNewFluid", body.to_dict(), NewFluidResult.from_dict)

    async def call_flash_async(
        self,
        body: FlashCalculationInput,
    ):
        """Perform flash calculation"""
        return await self.__post_async("Calculation/CallFlash", body.to_dict(), FlashCalculationResult.from_dict)

    async def call_cloud_point_async(
        self,
        body: CloudPointCalculationInput,
    ):
        """Perform cloud point calculation"""
        return await self.__post_async("Calculation/CallCloudPoint", body.to_dict(), CloudPointCalculationResult.from_dict)

    async def call_flashed_properties_async(
        self,
        body: FlashedPropertyCalculationInput,
    ):
        """Perform flash property calculation"""
        return await self.__post_async("Calculation/CallFlashedProperties", body.to_dict(), FlashedPropertyCalculationResult.from_dict)

    async def call_unflashed_properties_async(
        self,
        body: UnflashedPropertyCalculationInput,
    ):
        """Perform un-flash property calculation"""
        return await self.__post_async("Calculation/CallUnflashedProperties", body.to_dict(), UnflashedPropertyCalculationResult.from_dict)

    async def call_sle_point_async(
        self,
        body: SlePointCalculationInput,
    ):
        """Perform SLE point calculation"""
        return await self.__post_async("Calculation/CallSlePoint", body.to_dict(), SlePointCalculationResult.from_dict)

    async def call_calculation_phasediagram_standard_async(
        self,
        body: PhasediagramFixedTemperaturePressureCalculationInput,
    ):
        """Perform Phasediagram standard calculation"""
        return await self.__post_async("Calculation/CallCalculationPhasediagramStandard", body.to_dict(), PhasediagramFixedTemperaturePressureCalculationResult.from_dict)

    def get_flash_input(self):
        """Returns flash argument filled with standard input"""
        return FlashCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units())

    def get_cloud_point_input(self):
        """Returns cloud point argument filled with standard input"""
        return CloudPointCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units())

    def get_flashed_property_Input(self):
        """Returns flashed properties argument filled with standard input"""
        return FlashedPropertyCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units())

    def get_unflashed_property_input(self):
        """Returns un-flashed properties argument filled with standard input"""
        return UnflashedPropertyCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units())

    def get_sle_point_input(self):
        """Returns SLE point argument filled with standard input"""
        return SlePointCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units())

    def get_phasediagam_standard_input(self):
        """Returns phase diagram standard argument filled with standard input"""
        return PhasediagramFixedTemperaturePressureCalculationInput(user_id=self.__user_id, access_secret=self.__access_secret, units=self.__get_units())

    def get_request_fluid_input(self):
        """Returns request fluid argument filled with standard input"""
        return RequestFluidResult(user_id=self.__user_id, access_secret=self.__access_secret)

    def __get_units(self):
        return Units(temperature=UnitsItem(in_="Kelvin", out="Kelvin"), pressure=UnitsItem(in_="Kelvin", out="Kelvin"), composition=UnitsItem(in_="Kelvin", out="Kelvin"), enthalpy=UnitsItem(in_="kJ/Kg", out="kJ/Kg"), entropy=UnitsItem(in_="kJ/(Kg Kelvin)", out="kJ/(Kg Kelvin)"))



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiFluidPseudoComponent")


@attr.s(auto_attribs=True)
class ApiFluidPseudoComponent:
    """Information for a pseudo component"""

    sorting_order: Union[Unset, int] = UNSET
    name: Union[Unset, None, str] = UNSET
    melting_temperature: Union[Unset, float] = UNSET
    massfraction: Union[Unset, float] = UNSET
    molar_mass: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        sorting_order = self.sorting_order
        name = self.name
        melting_temperature = self.melting_temperature
        massfraction = self.massfraction
        molar_mass = self.molar_mass

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if sorting_order is not UNSET:
            field_dict["sortingOrder"] = sorting_order
        if name is not UNSET:
            field_dict["name"] = name
        if melting_temperature is not UNSET:
            field_dict["meltingTemperature"] = melting_temperature
        if massfraction is not UNSET:
            field_dict["massfraction"] = massfraction
        if molar_mass is not UNSET:
            field_dict["molarMass"] = molar_mass

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        sorting_order = d.pop("sortingOrder", UNSET)

        name = d.pop("name", UNSET)

        melting_temperature = d.pop("meltingTemperature", UNSET)

        massfraction = d.pop("massfraction", UNSET)

        molar_mass = d.pop("molarMass", UNSET)

        api_fluid_pseudo_component = cls(
            sorting_order=sorting_order,
            name=name,
            melting_temperature=melting_temperature,
            massfraction=massfraction,
            molar_mass=molar_mass,
        )

        return api_fluid_pseudo_component



from enum import Enum


class ComponentType(int, Enum):
    STANDARD = 0
    """0 - Standard"""
    POLYMER = 1
    """1 - Polymer"""
    CO_POLYMER = 2
    """2 - coPolymer"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiFluidKij")


@attr.s(auto_attribs=True)
class ApiFluidKij:
    """Set of Kij information"""

    index_i: Union[Unset, int] = UNSET
    index_j: Union[Unset, int] = UNSET
    kija: Union[Unset, float] = UNSET
    kijb: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        index_i = self.index_i
        index_j = self.index_j
        kija = self.kija
        kijb = self.kijb

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if index_i is not UNSET:
            field_dict["indexI"] = index_i
        if index_j is not UNSET:
            field_dict["indexJ"] = index_j
        if kija is not UNSET:
            field_dict["kija"] = kija
        if kijb is not UNSET:
            field_dict["kijb"] = kijb

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        index_i = d.pop("indexI", UNSET)

        index_j = d.pop("indexJ", UNSET)

        kija = d.pop("kija", UNSET)

        kijb = d.pop("kijb", UNSET)

        api_fluid_kij = cls(
            index_i=index_i,
            index_j=index_j,
            kija=kija,
            kijb=kijb,
        )

        return api_fluid_kij



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RequestFluidInput")


@attr.s(auto_attribs=True)
class RequestFluidInput:
    """Input for request fluid information"""

    user_id: str
    access_secret: str
    fluid_id: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        user_id = self.user_id
        access_secret = self.access_secret
        fluid_id = self.fluid_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "userId": user_id,
                "accessSecret": access_secret,
            }
        )
        if fluid_id is not UNSET:
            field_dict["fluidId"] = fluid_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_id = d.pop("userId")

        access_secret = d.pop("accessSecret")

        fluid_id = d.pop("fluidId", UNSET)

        request_fluid_input = cls(
            user_id=user_id,
            access_secret=access_secret,
            fluid_id=fluid_id,
        )

        return request_fluid_input



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_output_calculation_result_phase_composition import ApiOutputCalculationResultPhaseComposition
from ..models.api_output_calculation_result_phase_polymer_moments import ApiOutputCalculationResultPhasePolymerMoments
from ..models.api_value_with_units_density import ApiValueWithUnitsDensity
from ..models.api_value_with_units_enthalpy import ApiValueWithUnitsEnthalpy
from ..models.api_value_with_units_entropy import ApiValueWithUnitsEntropy
from ..models.api_value_with_units_volume import ApiValueWithUnitsVolume
from ..models.api_value_with_units_volume_mole_percent import ApiValueWithUnitsVolumeMolePercent
from ..models.api_value_with_units_volume_weight_percent import ApiValueWithUnitsVolumeWeightPercent
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputCalculationResultPhase")


@attr.s(auto_attribs=True)
class ApiOutputCalculationResultPhase:
    """Holds all properties for a phase"""

    phase_label: Union[Unset, None, str] = UNSET
    volume: Union[Unset, ApiValueWithUnitsVolume] = UNSET
    density: Union[Unset, ApiValueWithUnitsDensity] = UNSET
    entropy: Union[Unset, ApiValueWithUnitsEntropy] = UNSET
    enthalpy: Union[Unset, ApiValueWithUnitsEnthalpy] = UNSET
    mole_percent: Union[Unset, ApiValueWithUnitsVolumeMolePercent] = UNSET
    weight_percent: Union[Unset, ApiValueWithUnitsVolumeWeightPercent] = UNSET
    polymer_moments: Union[Unset, ApiOutputCalculationResultPhasePolymerMoments] = UNSET
    composition: Union[Unset, ApiOutputCalculationResultPhaseComposition] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        phase_label = self.phase_label
        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        density: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.density, Unset):
            density = self.density.to_dict()

        entropy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.entropy, Unset):
            entropy = self.entropy.to_dict()

        enthalpy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.enthalpy, Unset):
            enthalpy = self.enthalpy.to_dict()

        mole_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.mole_percent, Unset):
            mole_percent = self.mole_percent.to_dict()

        weight_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.weight_percent, Unset):
            weight_percent = self.weight_percent.to_dict()

        polymer_moments: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.polymer_moments, Unset):
            polymer_moments = self.polymer_moments.to_dict()

        composition: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.composition, Unset):
            composition = self.composition.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if phase_label is not UNSET:
            field_dict["phaseLabel"] = phase_label
        if volume is not UNSET:
            field_dict["volume"] = volume
        if density is not UNSET:
            field_dict["density"] = density
        if entropy is not UNSET:
            field_dict["entropy"] = entropy
        if enthalpy is not UNSET:
            field_dict["enthalpy"] = enthalpy
        if mole_percent is not UNSET:
            field_dict["molePercent"] = mole_percent
        if weight_percent is not UNSET:
            field_dict["weightPercent"] = weight_percent
        if polymer_moments is not UNSET:
            field_dict["polymerMoments"] = polymer_moments
        if composition is not UNSET:
            field_dict["composition"] = composition

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        phase_label = d.pop("phaseLabel", UNSET)

        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, ApiValueWithUnitsVolume]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = ApiValueWithUnitsVolume.from_dict(_volume)

        _density = d.pop("density", UNSET)
        density: Union[Unset, ApiValueWithUnitsDensity]
        if isinstance(_density, Unset):
            density = UNSET
        else:
            density = ApiValueWithUnitsDensity.from_dict(_density)

        _entropy = d.pop("entropy", UNSET)
        entropy: Union[Unset, ApiValueWithUnitsEntropy]
        if isinstance(_entropy, Unset):
            entropy = UNSET
        else:
            entropy = ApiValueWithUnitsEntropy.from_dict(_entropy)

        _enthalpy = d.pop("enthalpy", UNSET)
        enthalpy: Union[Unset, ApiValueWithUnitsEnthalpy]
        if isinstance(_enthalpy, Unset):
            enthalpy = UNSET
        else:
            enthalpy = ApiValueWithUnitsEnthalpy.from_dict(_enthalpy)

        _mole_percent = d.pop("molePercent", UNSET)
        mole_percent: Union[Unset, ApiValueWithUnitsVolumeMolePercent]
        if isinstance(_mole_percent, Unset):
            mole_percent = UNSET
        else:
            mole_percent = ApiValueWithUnitsVolumeMolePercent.from_dict(_mole_percent)

        _weight_percent = d.pop("weightPercent", UNSET)
        weight_percent: Union[Unset, ApiValueWithUnitsVolumeWeightPercent]
        if isinstance(_weight_percent, Unset):
            weight_percent = UNSET
        else:
            weight_percent = ApiValueWithUnitsVolumeWeightPercent.from_dict(_weight_percent)

        _polymer_moments = d.pop("polymerMoments", UNSET)
        polymer_moments: Union[Unset, ApiOutputCalculationResultPhasePolymerMoments]
        if isinstance(_polymer_moments, Unset):
            polymer_moments = UNSET
        else:
            polymer_moments = ApiOutputCalculationResultPhasePolymerMoments.from_dict(_polymer_moments)

        _composition = d.pop("composition", UNSET)
        composition: Union[Unset, ApiOutputCalculationResultPhaseComposition]
        if isinstance(_composition, Unset):
            composition = UNSET
        else:
            composition = ApiOutputCalculationResultPhaseComposition.from_dict(_composition)

        api_output_calculation_result_phase = cls(
            phase_label=phase_label,
            volume=volume,
            density=density,
            entropy=entropy,
            enthalpy=enthalpy,
            mole_percent=mole_percent,
            weight_percent=weight_percent,
            polymer_moments=polymer_moments,
            composition=composition,
        )

        return api_output_calculation_result_phase



""" Contains all the data models used in inputs/outputs """

from onlinepvt.models.api_call_result import ApiCallResult
from onlinepvt.models.api_fluid import ApiFluid
from onlinepvt.models.api_fluid_component_block import ApiFluidComponentBlock
from onlinepvt.models.api_fluid_kij import ApiFluidKij
from onlinepvt.models.api_fluid_polymer_component import ApiFluidPolymerComponent
from onlinepvt.models.api_fluid_pseudo_component import ApiFluidPseudoComponent
from onlinepvt.models.api_fluid_standard_component import ApiFluidStandardComponent
from onlinepvt.models.api_output_calculation_result_phase import ApiOutputCalculationResultPhase
from onlinepvt.models.api_output_calculation_result_phase_composition import ApiOutputCalculationResultPhaseComposition
from onlinepvt.models.api_output_calculation_result_phase_polymer_moment import ApiOutputCalculationResultPhasePolymerMoment
from onlinepvt.models.api_output_calculation_result_phase_polymer_moments import ApiOutputCalculationResultPhasePolymerMoments
from onlinepvt.models.api_output_calculation_result_point import ApiOutputCalculationResultPoint
from onlinepvt.models.api_output_phasediagram import ApiOutputPhasediagram
from onlinepvt.models.api_output_phasediagram_point import ApiOutputPhasediagramPoint
from onlinepvt.models.api_output_unflashed_property_result import ApiOutputUnflashedPropertyResult
from onlinepvt.models.api_output_unflashed_property_result_ideal import ApiOutputUnflashedPropertyResultIdeal
from onlinepvt.models.api_output_unflashed_property_result_residual import ApiOutputUnflashedPropertyResultResidual
from onlinepvt.models.api_value_floating_with_out_units import ApiValueFloatingWithOutUnits
from onlinepvt.models.api_value_floating_with_out_units_name import ApiValueFloatingWithOutUnitsName
from onlinepvt.models.api_value_floating_with_units import ApiValueFloatingWithUnits
from onlinepvt.models.api_value_with_units_composition_array import ApiValueWithUnitsCompositionArray
from onlinepvt.models.api_value_with_units_density import ApiValueWithUnitsDensity
from onlinepvt.models.api_value_with_units_enthalpy import ApiValueWithUnitsEnthalpy
from onlinepvt.models.api_value_with_units_entropy import ApiValueWithUnitsEntropy
from onlinepvt.models.api_value_with_units_pressure import ApiValueWithUnitsPressure
from onlinepvt.models.api_value_with_units_temperature import ApiValueWithUnitsTemperature
from onlinepvt.models.api_value_with_units_volume import ApiValueWithUnitsVolume
from onlinepvt.models.api_value_with_units_volume_mole_percent import ApiValueWithUnitsVolumeMolePercent
from onlinepvt.models.api_value_with_units_volume_weight_percent import ApiValueWithUnitsVolumeWeightPercent
from onlinepvt.models.association_scheme import AssociationScheme
from onlinepvt.models.calculation_block_info import CalculationBlockInfo
from onlinepvt.models.calculation_composition import CalculationComposition
from onlinepvt.models.cloud_point_calculation_input import CloudPointCalculationInput
from onlinepvt.models.cloud_point_calculation_result import CloudPointCalculationResult
from onlinepvt.models.cloud_point_calculation_type import CloudPointCalculationType
from onlinepvt.models.component_type import ComponentType
from onlinepvt.models.cp_model import CpModel
from onlinepvt.models.distribution_model import DistributionModel
from onlinepvt.models.eos_model import EosModel
from onlinepvt.models.exception_info import ExceptionInfo
from onlinepvt.models.flash_calculation_input import FlashCalculationInput
from onlinepvt.models.flash_calculation_result import FlashCalculationResult
from onlinepvt.models.flash_calculation_type import FlashCalculationType
from onlinepvt.models.flashed_property_calculation_input import FlashedPropertyCalculationInput
from onlinepvt.models.flashed_property_calculation_result import FlashedPropertyCalculationResult
from onlinepvt.models.fluid_distribution_moment import FluidDistributionMoment
from onlinepvt.models.is_alkane import IsAlkane
from onlinepvt.models.message_type import MessageType
from onlinepvt.models.new_fluid_input import NewFluidInput
from onlinepvt.models.new_fluid_result import NewFluidResult
from onlinepvt.models.phasediagram_fixed_temperature_pressure_calculation_input import (
    PhasediagramFixedTemperaturePressureCalculationInput,
)
from onlinepvt.models.phasediagram_fixed_temperature_pressure_calculation_result import (
    PhasediagramFixedTemperaturePressureCalculationResult,
)
from onlinepvt.models.polymer_type import PolymerType
from onlinepvt.models.problem_details import ProblemDetails
from onlinepvt.models.profile_information import ProfileInformation
from onlinepvt.models.profile_steps import ProfileSteps
from onlinepvt.models.profile_time_information import ProfileTimeInformation
from onlinepvt.models.properties_calculation_type import PropertiesCalculationType
from onlinepvt.models.property_reference_point import PropertyReferencePoint
from onlinepvt.models.request_fluid_input import RequestFluidInput
from onlinepvt.models.request_fluid_result import RequestFluidResult
from onlinepvt.models.sle_point_calculation_input import SlePointCalculationInput
from onlinepvt.models.sle_point_calculation_result import SlePointCalculationResult
from onlinepvt.models.sle_point_calculation_type import SlePointCalculationType
from onlinepvt.models.unflashed_property_calculation_input import UnflashedPropertyCalculationInput
from onlinepvt.models.unflashed_property_calculation_result import UnflashedPropertyCalculationResult
from onlinepvt.models.units import Units
from onlinepvt.models.units_item import UnitsItem
from onlinepvt.models.user_point_output import UserPointOutput



from enum import Enum


class CloudPointCalculationType(int, Enum):
    FIXED_TEMPERATURE = 0
    """0 - Fixed Temperature"""
    FIXED_PRESSURE = 1
    """1 - Fixed Pressure"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserPointOutput")


@attr.s(auto_attribs=True)
class UserPointOutput:
    """Output requested by user"""

    composition: Union[Unset, bool] = UNSET
    phase_fractions: Union[Unset, bool] = UNSET
    density: Union[Unset, bool] = UNSET
    molar_volume: Union[Unset, bool] = UNSET
    compressibility: Union[Unset, bool] = UNSET
    enthalpy: Union[Unset, bool] = UNSET
    entropy: Union[Unset, bool] = UNSET
    heat_capacity: Union[Unset, bool] = UNSET
    velocity_of_sound: Union[Unset, bool] = UNSET
    joule_thomson_coefficient: Union[Unset, bool] = UNSET
    molecular_weight: Union[Unset, bool] = UNSET
    distribution: Union[Unset, bool] = UNSET
    mn_mw_mz: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        composition = self.composition
        phase_fractions = self.phase_fractions
        density = self.density
        molar_volume = self.molar_volume
        compressibility = self.compressibility
        enthalpy = self.enthalpy
        entropy = self.entropy
        heat_capacity = self.heat_capacity
        velocity_of_sound = self.velocity_of_sound
        joule_thomson_coefficient = self.joule_thomson_coefficient
        molecular_weight = self.molecular_weight
        distribution = self.distribution
        mn_mw_mz = self.mn_mw_mz

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if composition is not UNSET:
            field_dict["composition"] = composition
        if phase_fractions is not UNSET:
            field_dict["phaseFractions"] = phase_fractions
        if density is not UNSET:
            field_dict["density"] = density
        if molar_volume is not UNSET:
            field_dict["molarVolume"] = molar_volume
        if compressibility is not UNSET:
            field_dict["compressibility"] = compressibility
        if enthalpy is not UNSET:
            field_dict["enthalpy"] = enthalpy
        if entropy is not UNSET:
            field_dict["entropy"] = entropy
        if heat_capacity is not UNSET:
            field_dict["heatCapacity"] = heat_capacity
        if velocity_of_sound is not UNSET:
            field_dict["velocityOfSound"] = velocity_of_sound
        if joule_thomson_coefficient is not UNSET:
            field_dict["jouleThomsonCoefficient"] = joule_thomson_coefficient
        if molecular_weight is not UNSET:
            field_dict["molecularWeight"] = molecular_weight
        if distribution is not UNSET:
            field_dict["distribution"] = distribution
        if mn_mw_mz is not UNSET:
            field_dict["mnMwMz"] = mn_mw_mz

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        composition = d.pop("composition", UNSET)

        phase_fractions = d.pop("phaseFractions", UNSET)

        density = d.pop("density", UNSET)

        molar_volume = d.pop("molarVolume", UNSET)

        compressibility = d.pop("compressibility", UNSET)

        enthalpy = d.pop("enthalpy", UNSET)

        entropy = d.pop("entropy", UNSET)

        heat_capacity = d.pop("heatCapacity", UNSET)

        velocity_of_sound = d.pop("velocityOfSound", UNSET)

        joule_thomson_coefficient = d.pop("jouleThomsonCoefficient", UNSET)

        molecular_weight = d.pop("molecularWeight", UNSET)

        distribution = d.pop("distribution", UNSET)

        mn_mw_mz = d.pop("mnMwMz", UNSET)

        user_point_output = cls(
            composition=composition,
            phase_fractions=phase_fractions,
            density=density,
            molar_volume=molar_volume,
            compressibility=compressibility,
            enthalpy=enthalpy,
            entropy=entropy,
            heat_capacity=heat_capacity,
            velocity_of_sound=velocity_of_sound,
            joule_thomson_coefficient=joule_thomson_coefficient,
            molecular_weight=molecular_weight,
            distribution=distribution,
            mn_mw_mz=mn_mw_mz,
        )

        return user_point_output



from enum import Enum


class SlePointCalculationType(int, Enum):
    FIXED_PRESSURE = 0
    """0 - Fixed Pressure"""
    FIXED_TP = 1
    """1 - Fixed Temperature/Pressure"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiValueWithUnitsEnthalpy")


@attr.s(auto_attribs=True)
class ApiValueWithUnitsEnthalpy:
    """Holds enthalpy information"""

    units: Union[Unset, None, str] = UNSET
    value: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        units = self.units
        value = self.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if units is not UNSET:
            field_dict["units"] = units
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        units = d.pop("units", UNSET)

        value = d.pop("value", UNSET)

        api_value_with_units_enthalpy = cls(
            units=units,
            value=value,
        )

        return api_value_with_units_enthalpy



from enum import Enum


class DistributionModel(int, Enum):
    GAMMA = 0
    """0 - Gamma"""
    LN_NORMAL = 1
    """1 - LnNormal"""
    BETA = 2
    """2 - Beta"""
    CHI_SQUARE = 3
    """3 - ChiSquare"""

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputPhasediagramPoint")


@attr.s(auto_attribs=True)
class ApiOutputPhasediagramPoint:
    """Result for a point"""

    temperature: Union[Unset, float] = UNSET
    pressure: Union[Unset, float] = UNSET
    label: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        temperature = self.temperature
        pressure = self.pressure
        label = self.label

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if pressure is not UNSET:
            field_dict["pressure"] = pressure
        if label is not UNSET:
            field_dict["label"] = label

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        temperature = d.pop("temperature", UNSET)

        pressure = d.pop("pressure", UNSET)

        label = d.pop("label", UNSET)

        api_output_phasediagram_point = cls(
            temperature=temperature,
            pressure=pressure,
            label=label,
        )

        return api_output_phasediagram_point



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_output_calculation_result_phase_polymer_moment import ApiOutputCalculationResultPhasePolymerMoment
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputCalculationResultPhasePolymerMoments")


@attr.s(auto_attribs=True)
class ApiOutputCalculationResultPhasePolymerMoments:
    """Polymer moments"""

    moment_units: Union[Unset, None, str] = UNSET
    polymers: Union[Unset, None, List[ApiOutputCalculationResultPhasePolymerMoment]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        moment_units = self.moment_units
        polymers: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.polymers, Unset):
            if self.polymers is None:
                polymers = None
            else:
                polymers = []
                for polymers_item_data in self.polymers:
                    polymers_item = polymers_item_data.to_dict()

                    polymers.append(polymers_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if moment_units is not UNSET:
            field_dict["momentUnits"] = moment_units
        if polymers is not UNSET:
            field_dict["polymers"] = polymers

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        moment_units = d.pop("momentUnits", UNSET)

        polymers = []
        _polymers = d.pop("polymers", UNSET)
        for polymers_item_data in _polymers or []:
            polymers_item = ApiOutputCalculationResultPhasePolymerMoment.from_dict(polymers_item_data)

            polymers.append(polymers_item)

        api_output_calculation_result_phase_polymer_moments = cls(
            moment_units=moment_units,
            polymers=polymers,
        )

        return api_output_calculation_result_phase_polymer_moments
